#
# spec file for package live555
#
# Copyright (c) 2015 SUSE LINUX Products GmbH, Nuernberg, Germany.
# Copyright (c) 2013 Dominique Leuenberger, Amsterdam, The Netherlands
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           live555
Version:        2015.01.27
Release:        4.2
Summary:        LIVE555 Streaming Media
License:        LGPL-2.1
Group:          System/Libraries
Url:            http://www.live555.com/liveMedia/
Source:         http://www.live555.com/liveMedia/public/live.%{version}.tar.gz
# PATCH-MISSING-TAG -- See http://wiki.opensuse.org/openSUSE:Packaging_Patches_guidelines
Patch0:         %{name}-fpic.patch
BuildRequires:  gcc-c++
BuildRequires:  pkg-config
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
This code forms a set of C++ libraries for multimedia streaming,
using open standard protocols (RTP/RTCP, RTSP, SIP). These libraries
can be used to build streaming applications

%package devel
Summary:        LIVE555 Streaming Media
Group:          Development/Languages/C and C++
# Actually, live555 is a devel package only. Headers, code and a static lib is all there is.
Provides:       %{name} = %{version}
Obsoletes:      %{name} < %{version}

%description devel
This code forms a set of C++ libraries for multimedia streaming,
using open standard protocols (RTP/RTCP, RTSP, SIP). These libraries
can be used to build streaming applications

%prep
%setup -q -n live
%patch0 -p1

%build
export CFLAGS="%{optflags}"
export CPPFLAGS="%{optflags}"
./genMakefiles linux
make %{?_smp_mflags}

%install
install -d -m 755 %{buildroot}%{_libdir}/live
install -d -m 755 %{buildroot}%{_includedir}
find . -type f -name "*.a" -exec install -m 644 {} %{buildroot}%{_libdir}/live \;
for fld in liveMedia groupsock BasicUsageEnvironment UsageEnvironment; do
  install -d -m 755 %{buildroot}%{_includedir}/$fld
  cp -rL $fld/include/* %{buildroot}%{_includedir}/$fld
done

# creates support file for pkg-config
mkdir %{buildroot}/%{_libdir}/pkgconfig
tee %{buildroot}/%{_libdir}/pkgconfig/live555.pc << "EOF"
prefix=%{_prefix}
exec_prefix=${prefix}
libdir=${exec_prefix}/%{_lib}
includedir=${prefix}/include

Name: live555
Description: Multimedia streaming libraries
Version: %{version}
Libs: -L${libdir}/live -lliveMedia -lUsageEnvironment -lgroupsock -lBasicUsageEnvironment
Cflags: -I${includedir}/liveMedia -I${includedir}/UsageEnvironment -I${includedir}/groupsock -I${includedir}/BasicUsageEnvironment
EOF

%files devel
%defattr(-,root,root)
%{_libdir}/live/
%{_includedir}/liveMedia/
%{_includedir}/groupsock/
%{_includedir}/BasicUsageEnvironment/
%{_includedir}/UsageEnvironment/
%{_libdir}/pkgconfig/live555.pc

%changelog
* Sat Jan 31 2015 aloisio@gmx.com
- fixed paths in live555.pc
- update to version 2015.01.27:
  * Fixed a bug in "MPEG2TransportStreamFromESSource" that could
    sometimes cause an abort if more than one Elementary Stream
    Source were multiplexed into a single Transport Stream.
    (Thanks to Marc Palau for reporting this issue.)
- version 2015.01.19:
  * Fixed an obscure bug in "RTSPClient" that might conceivably
    have caused a crash if it received a completely empty RTSP
    response.
- version 2015.01.04:
  * Updated "config.iphone-simulator" to work with the latest Xcode.
    (Thanks to Braden Ackerman.)
  * In the "BasicUsageEnvironment" implementation, renamed
    "EventTime" to "_EventTime" to avoid a reported naming conflict.
- version 2014.12.17:
  * Updated "RTSPServerSupportingHTTPStreaming" to make sure that
    the data stream source gets closed when it's no longer needed.
- version 2014.12.16:
  * Changed the FD_SETSIZE check (introduced in version 2014.12.11)
    so that it's not done in Windows (because in Windows,
    FD_SETSIZE has different semantics).
    (Thanks to Deanna Earley for reporting this.)
- version 2014.12.13:
  * Updated the H.264/H.265 parsing code in "H264or5VideoStreamFramer"
    to be a little smarter about how it computes a file's frame rate
    (when streaming a 'raw' H.264 or H.265 file).
    (Thanks to Michel Promonet for inspiring this.)
  * Updated "config.iphoneos" to work with the latest Xcode.
    (Thanks to Braden Ackerman.)
- version 2014.12.11:
  * Changed our implementation of "setBackgroundHandling()" and
    "moveBackgroundHandling()" in "BasicTaskScheduler" to check for
    (and disallow) socket numbers >= FD_SETSIZE, because <sys/select.h>
    has a bug (at least, in most systems) that causes buffer overflow
    in this case.  (Thanks to Michel Promonet for pointing this out.)
- version 2014.12.09:
  * Needed to make the "QuickTimeFileSink" constructor and destructor
    protected: to allow subclassing.
- version 2014.12.08:
  * Fixed a bug in parsing 'absolute' RTSP "Range:" headers with no end
    time. (Thanks to Ken Chow for reporting this.)
  * Added a new option "-K" to "openRTSP, to tell the client to
    periodically send "OPTIONS" requests as 'keep-alives' for buggy
    servers that don't use incoming RTCP "RR" packets to indicate client
    liveness.  (Thanks to Peter Schlaile for this suggestion.)
  * Added a new 'protected' virtual member function "noteRecordedFrame()"
    to "QuickTimeFileSink". This function is called whenever a frame is
    recorded to the output file. The default implementation of this
    virtual function does nothing, but subclasses can redefine it if
    they wish.
- version 2014.11.28:
  * When "RTSPClient" parses a RTSP response, we first skip over any
    blank lines that may be at the start of the response.  This can
    happen if the previous response (e.g., to a "DESCRIBE") contained
    extra whitespace. (Thanks to ilwoo Nam for giving an example of
    a server that exhibited this behavior.)
- version 2014.11.12:
  * We had forgotten to initialize the "RTSPClient" member variable
  "fAllowBasicAuthentication" that we introduced in the previous
  version.
- version 2014.11.07:
  * Added a new "RTSPClient" member function "disallowBasicAuthentication()"
    that you can call if you don't want a RTSP client to perform 'basic'
    authentication (whcih involves sending the username and password over
    the network), even if the server asks for this.
    (Thanks to Tomasz Pala for this suggestion.)
  * Updated the debugging printout code in "RTCP.cpp" to identify all
    known RTCP payload types, even if we don't currently handle them.
    We also - when doing debugging printout - parse and print out
    the contents of SDES RTCP packets.
- version 2014.11.01:
  * Updated "RTSPClient" so that it reuses "fCurrentAuthenticator"
    if we previously updated it with data from a "WWW-Authenticate:"
    response, even if a non_NULL "authenticator" parameter was
    passed as a parameter to the command.  This reduces the number
    of authetication exchanges that take place if the server asks
    for authentication on more than one command in a RTSP session.
    (Thanks to Tomasz Pala for this suggestion.)
  * Updated "DigestAuthenticator" to allow for the possibility of
    "username" or "password" being NULL.
  * Updated the "RTSPServer" implementation to add an access check
    before the first "SETUP" (the one that doesn't include a
    session id), because it's possible, in principle, for a client
    to send such a "SETUP" without first sending a "DESCRIBE".
    Therefore, we need to perform access checks on both commands.
- version 2014.10.28:
  * Added support for the VP9 video RTP payload format (sending and
    receiving), including the demultiplexing and streaming of a VP9
    video track from a Matroska-format file.
  * Made "VP8VideoRTPSource" more robust against a bad first-byte
    header field in the payload.
- version 2014.10.21:
  * Increased the max output packet size for "MultiFramedRTPSink"
    and "RTCPInstance" from 1448 to 1456, because we had a report
    of problems when proxying incoming JPEG/RTP packets of this
    size (and because 1456 bytes still gives a packet size of no
    more than 1500 bytes when we add
    in IP, UDP, and UMTP headers).
- version 2014.10.20:
  * Increased the RTSP request and response buffer sizes from 10000
    to 20000 bytes, because we saw a RTSP stream (VP8 video) that
    had an extremely large "configuration=" string that was hiting
    the previous limit.
- version 2014.10.16:
  * Fixed the "RTSPServer" implementation to handle a rare race
    condition that could cause a "ServerMediaSession" object to
    be deleted while it was being used to implement "DESCRIBE".
    (Thanks to Michel Promonet for reporting this.)
- version 2014.10.07:
  * Fixed a bug in the "MultiFramedRTPSource" implementation where
    we weren't properly checking the size of incoming RTP packets
    that have the "CC" field (i.e., number of "CSRC" fields) non-zero.
  * Updated "Groupsock::output()" to be a virtual function.
    (This makes it possible to implement "Groupsock" subclasses that
    implement 'bump-in-the-stack' protocols (such as SRT(C)P) below
    RTP/RTCP.)
- version 2014.10.03:
  * Fixed a problem in the "timestampString()" routine that occurs
    if "time_t" is 64 bits, but we're on a 32-bit machine.
    (Thanks to Deanna Earley for reporting this.)
  * Updated the debugging output code in "RTCP.cpp" to make it
    clearer that SDES and APP packets are not invalid; just not
    (yet) handled by us.
* Wed Oct 29 2014 olaf@aepfle.de
- BuildRequire pkg-config to get rpm Provides/Requires pkgconfig(live555)
* Mon Oct  6 2014 aloisio@gmx.com
- Added support for pkg-config by creating the relevant .pc file
* Thu Oct  2 2014 dimstar@opensuse.org
- Update to 2014.09.22:
  + Changed the way in which the "RTSPServer" code handles incoming
    "OPTIONS" commands that contain a "Session:" header. If the
    "Session:" header contains a session id that does not exist,
    then we now return a "Session Not Found" error (even though the
    handling of the "OPTIONS" command is not session-specific).
    This new behavior will help proxy servers (that use our
    "RTSPServer" implementation as a 'back-end' server) better
    detect when the back-end server has restarted while streaming.
  + For all other changes since 2013.04.30, please see
    http://www.live555.com/liveMedia/public/changelog.txt.
* Mon Mar  4 2013 dimstar@opensuse.org
- Update to version 2013.04.30:
  + One year worth of updates... see changelog.
* Sun Feb  5 2012 dimstar@opensuse.org
- Update to version 2012.02.04:
  + Updated "WAVAudioFileSource" to read from its input file
    asynchronously, if possible, rather than doing a synchronous
    (blocking) read.
- Changes from version 2012.02.03:
  + Updated "RTSPClient" to - after receiving a "SETUP" response
    for a UDP stream - send a couple of short 'dummy' UDP packets
    to the server.  This will make it more likely that the
    incoming RTP/UDP packets will successfully traverse a NAT box
    (if the client is behind a NAT).  (Note that we don't do this
    for RTCP, because the client's regular RTCP "RR" packets will
    have the same effect.)
  + Changed the way that the "sessionId" member field in
    "MediaSubsession" is managed.  Its memory is now managed by
    "MediaSubsession" itself, rather than by "RTSPClient" (as it
    was previously).  With the previous behavior, "valgrind"
    (incorrectly) reported a possible memory leak. The new behavior
    should make 'valgrinerds' happy.
- Drop patches that were required by VideoLAN: fixed upstream:
  + live-getaddrinfo.patch
  + live-inet_ntop.patch
  + live-uselocale.patch
* Tue Jan 31 2012 dimstar@opensuse.org
- Update to version 2012.01.26.
* Wed Nov 16 2011 dominique-vlc.suse@leuenberger.net
- Rewrite part of the .spec file.., Cleaner installation.
* Wed Nov 16 2011 dominique-vlc.suse@leuenberger.net
- Add VideoLAN required patches for proper funtioning of live555:
  + live-getaddrinfo.patch
  + live-inet_ntop.patch
  + live-uselocale.patch
* Wed Nov 16 2011 dominique-vlc.suse@leuenberger.net
- Update to version 2011.11.08:
  + Added "VorbisAudioRTPSink" and "VorbisAudioRTPSource" for
    sending/receiving Vorbos audio RTP streams (based on RFC 5215).
  + Added "VP8VideoRTPSink" and "VP8VideoRTPSource" for
    sending/receiving VP8 video RTP streams.
  + Added support for extracting and streaming Vorbis audio tracks
    from Matroska (including WEBM) files.
  + Added support for extracting and streaming VP8 video tracks
    from Matroska (including WEBM) files.
  + Updated the "testOnDemandRTSPServer" and "LIVE555MediaServer"
    (source-code version only) applications to support streaming
    from ".webm' files.
  + Fixed frame durations for data extracted from Matroska tracks
    that don't have a 'default duration'.
  + Fixed a memory leak in "RTSPClient::sendOptionsCmd()".
* Sat Oct 22 2011 dominique-vlc.suse@leuenberger.net
- Update to version 2011.10.18:
  + Improved "RTSPServer" support for subdirectories in "rtsp://"
  URLs (handling this better for non-compliant clients that try to
  do a "SETUP" on agrregate URLs - when there is only a single
  subsession in the stream).
- Add a -devel subpackage, obsolete the now empty subpackage by it.
- Drop rpmlintrc file, as the devel files are now in a devel
  package.
* Thu Jun 30 2011 dominique-vlc.suse@leuenberger.net
- Update to version 2011.06.16
* Sat Oct  2 2010 dominique-vlc.suse@leuenberger.net
- Update to 2010.09.25
* Mon Aug 31 2009 dominique-vlc.suse@leuenberger.net
  2009.07.28:
- Updated "QuickTimeFileSink" to add a "stss" atom for video streams, following a suggestion by Gerardo Ares.
  (At present we just 'guess' which video 'samples' (frames) are 'key frames', so this might not work properly on some
  video streams.)
- Modified the "config.uClinux" configuration file, following a suggestion by Chetan Raj.
- Changed "RTSPClient"s implementation of the RTSP "TEARDOWN" command to always act as if the command succeeded, regardless of
  the actual response from the server (because, from the client's point of view, the session has ended).
  (This overcomes a potential memory leak, pointer out by Stuart Rawling.)
  2009.07.09:
- Modified the RTSP server implementation to - for streams where there is a known duration - always include a range end time
  in the RTSP "PLAY" response, even if the client did not specify one in the "PLAY" request.  This allows VLC's client
  'trick play' to (mostly) work.
- Updated "MediaSession::initiate()" to eliminate a possible memory leak if we get an error in socket creation.
  (Thanks to Denis Charmet.)
- Made a minor change to "MultiFramedRTPSink" to make monitoring/debugging easier.  (Thanks to Guy Bonneau.)
- Begun adding support for DV video.  However, this implementation is still incomplete.  DO NOT USE IT!
  2009.06.02:
- Updated the MPEG Transport Stream multiplexor implementation to allow for H.264 video.  (Thanks to Massimo Zito.)
- Updated "MultiFramedRTPSink" to allow for subclasses for RTP payload formats (such as DV, coming soon) that impose
  a granularity on RTP fragment sizes.
* Sun Apr 26 2009 dominique-suse.vlc@leuenberger.net
  2009.04.20:
- Fixed "BasicUsageEnvironment::getErrno()" to always (under Windows) return
  "WSAGetLastError()" (and to just ignore the "errno" variable>.
  Also fixed a few places in the code where we were still using "errno"
  instead of calling "getErrno()"
  2009.04.07:
- Changed many "char*" variables to "char const*" to eliminate possible compiler warnings.
  (Thanks to Sebastien Escudier for pointing out this issue.)
  2009.04.06:
- Modified our Windows-only version of "gettimeofday()" so that it now returns times based on the proper epoch.
  (Thanks to Patrick White for this suggestion.)
- Created a new config file for 64-bit Solaris, and renamed the old "config.solaris" file to make it
  clear that it's for 32-bit Solaris only.  (Thanks to ichael Skaastrup.)
- Modified "config.mingw" to add "-DLOCALE_NOT_USED" to the "COMPILE_OPTS =" line.  (The VLC folks seem to want
  this.)
- Made a minor change to some win32-specific code in "RTSPClient.cpp" that the VLC folks seem to like.
  (However, "RTSPClient" is about to undergo a major overhaul (for asynchronous I/O) anyway...)
- Made a small change to "mediaServer/DynamicRTSPServer.cpp" to eliminate compiler warnings on some platforms.
